antares.apps.obligation package — Antares 0.0.2 documentation

# antares.apps.obligation package

## Subpackages

- antares.apps.obligation.api package
  - Submodules
  - antares.apps.obligation.api.api_obligation_panel_complied_view module
  - antares.apps.obligation.api.api_obligation_panel_pending_view module
  - Module contents
- antares.apps.obligation.console package
  - Submodules
  - antares.apps.obligation.console.obligation_console module
  - Module contents
- antares.apps.obligation.exceptions package
  - Module contents
- antares.apps.obligation.manager package
  - Submodules
  - antares.apps.obligation.manager.obligation_manager module
  - Module contents
- antares.apps.obligation.migrations package
  - Submodules
  - antares.apps.obligation.migrations.0001_initial module
  - antares.apps.obligation.migrations.0002_auto_20180624_1759 module
  - Module contents
- antares.apps.obligation.models package
  - Submodules
  - antares.apps.obligation.models.client_obligation module
  - antares.apps.obligation.models.obligation_rule module
  - antares.apps.obligation.models.obligation_vector module
  - antares.apps.obligation.models.obligation_vector_log module
  - Module contents
- antares.apps.obligation.service package
  - Module contents
- antares.apps.obligation.tests package
  - Submodules
  - antares.apps.obligation.tests.obligation_test module
  - Module contents
- antares.apps.obligation.views package
  - Submodules
  - antares.apps.obligation.views.obligation_panel_view module
  - Module contents

## Submodules

## antares.apps.obligation.admin module

## antares.apps.obligation.apps module

class `antares.apps.obligation.apps.` `ObligationConfig`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'obligation'

## antares.apps.obligation.constants module

## antares.apps.obligation.urls module

## Module contents